@@ -1,23 +1,21 @@
+from typing import TYPE_CHECKING
+
 from astroid import nodes
 
 from pylint.checkers import BaseChecker
-from pylint.interfaces import IAstroidChecker
 
+if TYPE_CHECKING:
+    from pylint.lint import PyLinter
 
-# This is our checker class.
 # Checkers should always inherit from `BaseChecker`.
-class MyAstroidChecker(BaseChecker):
-    """Add class member attributes to the class locals dictionary."""
 
-    # This class variable defines the type of checker that we are implementing.
-    # In this case, we are implementing an AST checker.
-    __implements__ = IAstroidChecker
+
+class MyAstroidChecker(BaseChecker):
+    """Add class member attributes to the class local's dictionary."""
 
     # The name defines a custom section of the config for this checker.
     name = "custom"
-    # The priority indicates the order that pylint will run the checkers.
-    priority = -1
-    # This class variable declares the messages (ie the warnings and errors)
+    # This class variable declares the messages (i.e. the warnings and errors)
     # that the checker can emit.
     msgs = {
         # Each message has a code, a message that the user will see,
@@ -31,8 +29,7 @@ class MyAstroidChecker(BaseChecker):
     options = (
         # Each option definition has a name which is used on the command line
         # and in config files, and a dictionary of arguments
-        # (similar to those to those to
-        # argparse.ArgumentParser.add_argument).
+        # (similar to argparse.ArgumentParser.add_argument).
         (
             "store-locals-indicator",
             {
@@ -49,8 +46,6 @@ class MyAstroidChecker(BaseChecker):
         """Called when a :class:`.nodes.Call` node is visited.
 
         See :mod:`astroid` for the description of available nodes.
-
-        :param node: The node to check.
         """
         if not (
             isinstance(node.func, nodes.Attribute)
@@ -59,15 +54,14 @@ class MyAstroidChecker(BaseChecker):
             and node.func.attrname == "create"
         ):
             return
-        in_class = node.frame()
+        in_class = node.frame(future=True)
         for param in node.args:
             in_class.locals[param.name] = node
 
 
-def register(linter):
-    """This required method auto registers the checker.
+def register(linter: "PyLinter") -> None:
+    """This required method auto registers the checker during initialization.
 
     :param linter: The linter to register the checker to.
-    :type linter: pylint.lint.PyLinter
     """
     linter.register_checker(MyAstroidChecker(linter))
