@@ -32,7 +32,7 @@ class MyRawChecker(BaseRawFileChecker):
         the module's content is accessible via node.stream() function
         """
         with node.stream() as stream:
-            for (lineno, line) in enumerate(stream):
+            for lineno, line in enumerate(stream):
                 if line.rstrip().endswith("\\"):
                     self.add_message("backslash-line-continuation", line=lineno)
 
