@@ -1,5 +1,8 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+
+from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
@@ -9,9 +12,9 @@ if TYPE_CHECKING:
     from pylint.lint import PyLinter
 
 
-def initialize(linter: "PyLinter") -> None:
-    """Initialize linter with checkers in the extensions directory"""
-    register_plugins(linter, __path__[0])  # type: ignore[name-defined] # Fixed in https://github.com/python/mypy/pull/9454
+def initialize(linter: PyLinter) -> None:
+    """Initialize linter with checkers in the extensions' directory."""
+    register_plugins(linter, __path__[0])
 
 
 __all__ = ["initialize"]
