@@ -1,40 +1,22 @@
-# Copyright (c) 2016-2019, 2021 Ashley Whetter <ashley@awhetter.co.uk>
-# Copyright (c) 2016-2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2016 Yuri Bochkarev <baltazar.bz@gmail.com>
-# Copyright (c) 2016 Glenn Matthews <glenn@e-dad.net>
-# Copyright (c) 2016 Moises Lopez <moylop260@vauxoo.com>
-# Copyright (c) 2017, 2020 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2017 Mitar <mitar.github@tnode.com>
-# Copyright (c) 2018, 2020 Anthony Sottile <asottile@umich.edu>
-# Copyright (c) 2018 Jim Robertson <jrobertson98atx@gmail.com>
-# Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
-# Copyright (c) 2018 Mitchell T.H. Young <mitchelly@gmail.com>
-# Copyright (c) 2018 Adrian Chirieac <chirieacam@gmail.com>
-# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2019 Danny Hermes <daniel.j.hermes@gmail.com>
-# Copyright (c) 2019 Zeb Nicholls <zebedee.nicholls@climate-energy-college.org>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
-# Copyright (c) 2021 allanc65 <95424144+allanc65@users.noreply.github.com>
-# Copyright (c) 2021 Konstantina Saketou <56515303+ksaketou@users.noreply.github.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
 """Utility methods for docstring checking."""
 
+from __future__ import annotations
+
 import re
-from typing import List, Set, Tuple
 
 import astroid
 from astroid import nodes
+from astroid.util import Uninferable
 
 from pylint.checkers import utils
 
 
-def space_indentation(s):
-    """The number of leading spaces in a string
+def space_indentation(s: str) -> int:
+    """The number of leading spaces in a string.
 
     :param str s: input string
 
@@ -44,7 +26,7 @@ def space_indentation(s):
     return len(s) - len(s.lstrip(" "))
 
 
-def get_setters_property_name(node):
+def get_setters_property_name(node: nodes.FunctionDef) -> str | None:
     """Get the name of the property that the given node is a setter for.
 
     :param node: The node to get the property name for.
@@ -61,11 +43,11 @@ def get_setters_property_name(node):
             and decorator.attrname == "setter"
             and isinstance(decorator.expr, nodes.Name)
         ):
-            return decorator.expr.name
+            return decorator.expr.name  # type: ignore[no-any-return]
     return None
 
 
-def get_setters_property(node):
+def get_setters_property(node: nodes.FunctionDef) -> nodes.FunctionDef | None:
     """Get the property node for the given setter node.
 
     :param node: The node to get the property for.
@@ -80,7 +62,7 @@ def get_setters_property(node):
     property_name = get_setters_property_name(node)
     class_node = utils.node_frame_class(node)
     if property_name and class_node:
-        class_attrs = class_node.getattr(node.name)
+        class_attrs: list[nodes.FunctionDef] = class_node.getattr(node.name)
         for attr in class_attrs:
             if utils.decorated_with_property(attr):
                 property_ = attr
@@ -89,7 +71,7 @@ def get_setters_property(node):
     return property_
 
 
-def returns_something(return_node):
+def returns_something(return_node: nodes.Return) -> bool:
     """Check if a return node returns a value other than None.
 
     :param return_node: The return node to check.
@@ -107,7 +89,7 @@ def returns_something(return_node):
     return not (isinstance(returns, nodes.Const) and returns.value is None)
 
 
-def _get_raise_target(node):
+def _get_raise_target(node: nodes.NodeNG) -> nodes.NodeNG | Uninferable | None:
     if isinstance(node.exc, nodes.Call):
         func = node.exc.func
         if isinstance(func, (nodes.Name, nodes.Attribute)):
@@ -115,64 +97,72 @@ def _get_raise_target(node):
     return None
 
 
-def _split_multiple_exc_types(target: str) -> List[str]:
+def _split_multiple_exc_types(target: str) -> list[str]:
     delimiters = r"(\s*,(?:\s*or\s)?\s*|\s+or\s+)"
     return re.split(delimiters, target)
 
 
-def possible_exc_types(node):
-    """
-    Gets all of the possible raised exception types for the given raise node.
+def possible_exc_types(node: nodes.NodeNG) -> set[nodes.ClassDef]:
+    """Gets all the possible raised exception types for the given raise node.
 
     .. note::
 
         Caught exception types are ignored.
 
-
     :param node: The raise node to find exception types for.
-    :type node: nodes.NodeNG
 
     :returns: A list of exception types possibly raised by :param:`node`.
-    :rtype: set(str)
     """
-    excs = []
+    exceptions = []
     if isinstance(node.exc, nodes.Name):
         inferred = utils.safe_infer(node.exc)
         if inferred:
-            excs = [inferred.name]
+            exceptions = [inferred]
     elif node.exc is None:
         handler = node.parent
         while handler and not isinstance(handler, nodes.ExceptHandler):
             handler = handler.parent
 
         if handler and handler.type:
-            inferred_excs = astroid.unpack_infer(handler.type)
-            excs = (exc.name for exc in inferred_excs if exc is not astroid.Uninferable)
+            try:
+                for exception in astroid.unpack_infer(handler.type):
+                    if exception is not astroid.Uninferable:
+                        exceptions.append(exception)
+            except astroid.InferenceError:
+                pass
     else:
         target = _get_raise_target(node)
         if isinstance(target, nodes.ClassDef):
-            excs = [target.name]
+            exceptions = [target]
         elif isinstance(target, nodes.FunctionDef):
             for ret in target.nodes_of_class(nodes.Return):
-                if ret.frame() != target:
+                if ret.value is None:
+                    continue
+                if ret.frame(future=True) != target:
                     # return from inner function - ignore it
                     continue
 
                 val = utils.safe_infer(ret.value)
-                if (
-                    val
-                    and isinstance(val, (astroid.Instance, nodes.ClassDef))
-                    and utils.inherit_from_std_ex(val)
-                ):
-                    excs.append(val.name)
+                if val and utils.inherit_from_std_ex(val):
+                    if isinstance(val, nodes.ClassDef):
+                        exceptions.append(val)
+                    elif isinstance(val, astroid.Instance):
+                        exceptions.append(val.getattr("__class__")[0])
 
     try:
-        return {exc for exc in excs if not utils.node_ignores_exception(node, exc)}
+        return {
+            exc
+            for exc in exceptions
+            if not utils.node_ignores_exception(node, exc.name)
+        }
     except astroid.InferenceError:
         return set()
 
 
-def docstringify(docstring, default_type="default"):
+def docstringify(
+    docstring: nodes.Const | None, default_type: str = "default"
+) -> Docstring:
+    best_match = (0, DOCSTRING_TYPES.get(default_type, Docstring)(docstring))
     for docstring_type in (
         SphinxDocstring,
         EpytextDocstring,
@@ -180,11 +170,11 @@ def docstringify(docstring, default_type="default"):
         NumpyDocstring,
     ):
         instance = docstring_type(docstring)
-        if instance.is_valid():
-            return instance
+        matching_sections = instance.matching_sections()
+        if matching_sections > best_match[0]:
+            best_match = (matching_sections, instance)
 
-    docstring_type = DOCSTRING_TYPES.get(default_type, Docstring)
-    return docstring_type(docstring)
+    return best_match[1]
 
 
 class Docstring:
@@ -202,45 +192,45 @@ class Docstring:
     """
 
     # These methods are designed to be overridden
-    # pylint: disable=no-self-use
-    def __init__(self, doc):
-        doc = doc or ""
-        self.doc = doc.expandtabs()
+    def __init__(self, doc: nodes.Const | None) -> None:
+        docstring: str = doc.value if doc else ""
+        self.doc = docstring.expandtabs()
 
     def __repr__(self) -> str:
         return f"<{self.__class__.__name__}:'''{self.doc}'''>"
 
-    def is_valid(self):
-        return False
+    def matching_sections(self) -> int:
+        """Returns the number of matching docstring sections."""
+        return 0
 
-    def exceptions(self):
+    def exceptions(self) -> set[str]:
         return set()
 
-    def has_params(self):
+    def has_params(self) -> bool:
         return False
 
-    def has_returns(self):
+    def has_returns(self) -> bool:
         return False
 
-    def has_rtype(self):
+    def has_rtype(self) -> bool:
         return False
 
-    def has_property_returns(self):
+    def has_property_returns(self) -> bool:
         return False
 
-    def has_property_type(self):
+    def has_property_type(self) -> bool:
         return False
 
-    def has_yields(self):
+    def has_yields(self) -> bool:
         return False
 
-    def has_yields_type(self):
+    def has_yields_type(self) -> bool:
         return False
 
-    def match_param_docs(self):
+    def match_param_docs(self) -> tuple[set[str], set[str]]:
         return set(), set()
 
-    def params_documented_elsewhere(self):
+    def params_documented_elsewhere(self) -> bool:
         return self.re_for_parameters_see.search(self.doc) is not None
 
 
@@ -250,24 +240,24 @@ class SphinxDocstring(Docstring):
         \w(?:\w|\.[^\.])*    # Valid python name
         """
 
-    re_simple_container_type = fr"""
+    re_simple_container_type = rf"""
         {re_type}                     # a container type
         [\(\[] [^\n\s]+ [\)\]]        # with the contents of the container
     """
 
     re_multiple_simple_type = r"""
         (?:{container_type}|{type})
-        (?:(?:\s+(?:of|or)\s+|\s*,\s*)(?:{container_type}|{type}))*
+        (?:(?:\s+(?:of|or)\s+|\s*,\s*|\s+\|\s+)(?:{container_type}|{type}))*
     """.format(
         type=re_type, container_type=re_simple_container_type
     )
 
-    re_xref = fr"""
+    re_xref = rf"""
         (?::\w+:)?                    # optional tag
         `{re_type}`                   # what to reference
         """
 
-    re_param_raw = fr"""
+    re_param_raw = rf"""
         :                       # initial colon
         (?:                     # Sphinx keywords
         param|parameter|
@@ -281,13 +271,13 @@ class SphinxDocstring(Docstring):
         \s+
         )?
 
-        ((\\\*{{1,2}}\w+)|(\w+))  # Parameter name with potential asterisks
+        ((\\\*{{0,2}}\w+)|(\w+))  # Parameter name with potential asterisks
         \s*                       # whitespace
         :                         # final colon
         """
     re_param_in_docstring = re.compile(re_param_raw, re.X | re.S)
 
-    re_type_raw = fr"""
+    re_type_raw = rf"""
         :type                           # Sphinx keyword
         \s+                             # whitespace
         ({re_multiple_simple_type})     # Parameter name
@@ -296,14 +286,14 @@ class SphinxDocstring(Docstring):
         """
     re_type_in_docstring = re.compile(re_type_raw, re.X | re.S)
 
-    re_property_type_raw = fr"""
+    re_property_type_raw = rf"""
         :type:                      # Sphinx keyword
         \s+                         # whitespace
         {re_multiple_simple_type}   # type declaration
         """
     re_property_type_in_docstring = re.compile(re_property_type_raw, re.X | re.S)
 
-    re_raise_raw = fr"""
+    re_raise_raw = rf"""
         :                               # initial colon
         (?:                             # Sphinx keyword
         raises?|
@@ -322,17 +312,21 @@ class SphinxDocstring(Docstring):
 
     supports_yields = False
 
-    def is_valid(self):
-        return bool(
-            self.re_param_in_docstring.search(self.doc)
-            or self.re_raise_in_docstring.search(self.doc)
-            or self.re_rtype_in_docstring.search(self.doc)
-            or self.re_returns_in_docstring.search(self.doc)
-            or self.re_property_type_in_docstring.search(self.doc)
+    def matching_sections(self) -> int:
+        """Returns the number of matching docstring sections."""
+        return sum(
+            bool(i)
+            for i in (
+                self.re_param_in_docstring.search(self.doc),
+                self.re_raise_in_docstring.search(self.doc),
+                self.re_rtype_in_docstring.search(self.doc),
+                self.re_returns_in_docstring.search(self.doc),
+                self.re_property_type_in_docstring.search(self.doc),
+            )
         )
 
-    def exceptions(self):
-        types = set()
+    def exceptions(self) -> set[str]:
+        types: set[str] = set()
 
         for match in re.finditer(self.re_raise_in_docstring, self.doc):
             raise_type = match.group(1)
@@ -340,25 +334,25 @@ class SphinxDocstring(Docstring):
 
         return types
 
-    def has_params(self):
+    def has_params(self) -> bool:
         if not self.doc:
             return False
 
         return self.re_param_in_docstring.search(self.doc) is not None
 
-    def has_returns(self):
+    def has_returns(self) -> bool:
         if not self.doc:
             return False
 
         return bool(self.re_returns_in_docstring.search(self.doc))
 
-    def has_rtype(self):
+    def has_rtype(self) -> bool:
         if not self.doc:
             return False
 
         return bool(self.re_rtype_in_docstring.search(self.doc))
 
-    def has_property_returns(self):
+    def has_property_returns(self) -> bool:
         if not self.doc:
             return False
 
@@ -366,13 +360,13 @@ class SphinxDocstring(Docstring):
         # so the first line must not be a known directive.
         return not self.doc.lstrip().startswith(":")
 
-    def has_property_type(self):
+    def has_property_type(self) -> bool:
         if not self.doc:
             return False
 
         return bool(self.re_property_type_in_docstring.search(self.doc))
 
-    def match_param_docs(self):
+    def match_param_docs(self) -> tuple[set[str], set[str]]:
         params_with_doc = set()
         params_with_type = set()
 
@@ -390,8 +384,9 @@ class SphinxDocstring(Docstring):
 
 
 class EpytextDocstring(SphinxDocstring):
-    """
-    Epytext is similar to Sphinx. See the docs:
+    """Epytext is similar to Sphinx.
+
+    See the docs:
         http://epydoc.sourceforge.net/epytext.html
         http://epydoc.sourceforge.net/fields.html#fields
 
@@ -429,7 +424,7 @@ class EpytextDocstring(SphinxDocstring):
 
     re_returns_in_docstring = re.compile(r"@returns?:")
 
-    def has_property_returns(self):
+    def has_property_returns(self) -> bool:
         if not self.doc:
             return False
 
@@ -447,14 +442,14 @@ class GoogleDocstring(Docstring):
 
     re_xref = SphinxDocstring.re_xref
 
-    re_container_type = fr"""
+    re_container_type = rf"""
         (?:{re_type}|{re_xref})       # a container type
         [\(\[] [^\n]+ [\)\]]          # with the contents of the container
     """
 
     re_multiple_type = r"""
         (?:{container_type}|{type}|{xref})
-        (?:(?:\s+(?:of|or)\s+|\s*,\s*)(?:{container_type}|{type}|{xref}))*
+        (?:(?:\s+(?:of|or)\s+|\s*,\s*|\s+\|\s+)(?:{container_type}|{type}|{xref}))*
     """.format(
         type=re_type, xref=re_xref, container_type=re_container_type
     )
@@ -475,8 +470,8 @@ class GoogleDocstring(Docstring):
     )
 
     re_param_line = re.compile(
-        fr"""
-        \s*  (\*{{0,2}}\w+)             # identifier potentially with asterisks
+        rf"""
+        \s*  ((?:\\?\*{{0,2}})?[\w\\]+) # identifier potentially with asterisks or escaped `\`
         \s*  ( [(]
             {re_multiple_type}
             (?:,\s+optional)?
@@ -491,7 +486,7 @@ class GoogleDocstring(Docstring):
     )
 
     re_raise_line = re.compile(
-        fr"""
+        rf"""
         \s*  ({re_multiple_type}) \s* :  # identifier
         \s*  (.*)                        # beginning of optional description
     """,
@@ -503,7 +498,7 @@ class GoogleDocstring(Docstring):
     )
 
     re_returns_line = re.compile(
-        fr"""
+        rf"""
         \s* ({re_multiple_type}:)?        # identifier
         \s* (.*)                          # beginning of description
     """,
@@ -511,8 +506,8 @@ class GoogleDocstring(Docstring):
     )
 
     re_property_returns_line = re.compile(
-        fr"""
-        ^{re_multiple_type}:           # indentifier
+        rf"""
+        ^{re_multiple_type}:           # identifier
         \s* (.*)                       # Summary line / description
     """,
         re.X | re.S | re.M,
@@ -526,22 +521,26 @@ class GoogleDocstring(Docstring):
 
     supports_yields = True
 
-    def is_valid(self):
-        return bool(
-            self.re_param_section.search(self.doc)
-            or self.re_raise_section.search(self.doc)
-            or self.re_returns_section.search(self.doc)
-            or self.re_yields_section.search(self.doc)
-            or self.re_property_returns_line.search(self._first_line())
+    def matching_sections(self) -> int:
+        """Returns the number of matching docstring sections."""
+        return sum(
+            bool(i)
+            for i in (
+                self.re_param_section.search(self.doc),
+                self.re_raise_section.search(self.doc),
+                self.re_returns_section.search(self.doc),
+                self.re_yields_section.search(self.doc),
+                self.re_property_returns_line.search(self._first_line()),
+            )
         )
 
-    def has_params(self):
+    def has_params(self) -> bool:
         if not self.doc:
             return False
 
         return self.re_param_section.search(self.doc) is not None
 
-    def has_returns(self):
+    def has_returns(self) -> bool:
         if not self.doc:
             return False
 
@@ -557,7 +556,7 @@ class GoogleDocstring(Docstring):
 
         return False
 
-    def has_rtype(self):
+    def has_rtype(self) -> bool:
         if not self.doc:
             return False
 
@@ -573,7 +572,7 @@ class GoogleDocstring(Docstring):
 
         return False
 
-    def has_property_returns(self):
+    def has_property_returns(self) -> bool:
         # The summary line is the return doc,
         # so the first line must not be a known directive.
         first_line = self._first_line()
@@ -584,13 +583,13 @@ class GoogleDocstring(Docstring):
             or self.re_yields_section.search(first_line)
         )
 
-    def has_property_type(self):
+    def has_property_type(self) -> bool:
         if not self.doc:
             return False
 
         return bool(self.re_property_returns_line.match(self._first_line()))
 
-    def has_yields(self):
+    def has_yields(self) -> bool:
         if not self.doc:
             return False
 
@@ -606,7 +605,7 @@ class GoogleDocstring(Docstring):
 
         return False
 
-    def has_yields_type(self):
+    def has_yields_type(self) -> bool:
         if not self.doc:
             return False
 
@@ -622,8 +621,8 @@ class GoogleDocstring(Docstring):
 
         return False
 
-    def exceptions(self):
-        types = set()
+    def exceptions(self) -> set[str]:
+        types: set[str] = set()
 
         entries = self._parse_section(self.re_raise_section)
         for entry in entries:
@@ -638,9 +637,9 @@ class GoogleDocstring(Docstring):
 
         return types
 
-    def match_param_docs(self):
-        params_with_doc = set()
-        params_with_type = set()
+    def match_param_docs(self) -> tuple[set[str], set[str]]:
+        params_with_doc: set[str] = set()
+        params_with_type: set[str] = set()
 
         entries = self._parse_section(self.re_param_section)
         entries.extend(self._parse_section(self.re_keyword_param_section))
@@ -650,6 +649,9 @@ class GoogleDocstring(Docstring):
                 continue
 
             param_name = match.group(1)
+            # Remove escape characters necessary for asterisks
+            param_name = param_name.replace("\\", "")
+
             param_type = match.group(2)
             param_desc = match.group(3)
 
@@ -661,28 +663,28 @@ class GoogleDocstring(Docstring):
 
         return params_with_doc, params_with_type
 
-    def _first_line(self):
+    def _first_line(self) -> str:
         return self.doc.lstrip().split("\n", 1)[0]
 
     @staticmethod
-    def min_section_indent(section_match):
+    def min_section_indent(section_match: re.Match[str]) -> int:
         return len(section_match.group(1)) + 1
 
     @staticmethod
-    def _is_section_header(_):
+    def _is_section_header(_: str) -> bool:
         # Google parsing does not need to detect section headers,
         # because it works off of indentation level only
         return False
 
-    def _parse_section(self, section_re):
+    def _parse_section(self, section_re: re.Pattern[str]) -> list[str]:
         section_match = section_re.search(self.doc)
         if section_match is None:
             return []
 
         min_indentation = self.min_section_indent(section_match)
 
-        entries = []
-        entry = []
+        entries: list[str] = []
+        entry: list[str] = []
         is_first = True
         for line in section_match.group(2).splitlines():
             if not line.strip():
@@ -726,11 +728,25 @@ class NumpyDocstring(GoogleDocstring):
         re.X | re.S | re.M,
     )
 
+    re_default_value = r"""((['"]\w+\s*['"])|(\d+)|(True)|(False)|(None))"""
+
     re_param_line = re.compile(
-        fr"""
-        \s*  (\*{{0,2}}\w+)(\s?(:|\n))                                      # identifier with potential asterisks
-        \s*  (?:({GoogleDocstring.re_multiple_type})(?:,\s+optional)?\n)?   # optional type declaration
-        \s* (.*)                                                            # optional description
+        rf"""
+        \s*  (?P<param_name>\*{{0,2}}\w+)(\s?(:|\n)) # identifier with potential asterisks
+        \s*
+        (?P<param_type>
+         (
+          ({GoogleDocstring.re_multiple_type})      # default type declaration
+          (,\s+optional)?                           # optional 'optional' indication
+         )?
+         (
+          {{({re_default_value},?\s*)+}}            # set of default values
+         )?
+         (?:$|\n)
+        )?
+        (
+         \s* (?P<param_desc>.*)                     # optional description
+        )?
     """,
         re.X | re.S,
     )
@@ -740,7 +756,7 @@ class NumpyDocstring(GoogleDocstring):
     )
 
     re_raise_line = re.compile(
-        fr"""
+        rf"""
         \s* ({GoogleDocstring.re_type})$   # type declaration
         \s* (.*)                           # optional description
     """,
@@ -752,7 +768,7 @@ class NumpyDocstring(GoogleDocstring):
     )
 
     re_returns_line = re.compile(
-        fr"""
+        rf"""
         \s* (?:\w+\s+:\s+)? # optional name
         ({GoogleDocstring.re_multiple_type})$   # type declaration
         \s* (.*)                                # optional description
@@ -768,8 +784,8 @@ class NumpyDocstring(GoogleDocstring):
 
     supports_yields = True
 
-    def match_param_docs(self) -> Tuple[Set[str], Set[str]]:
-        """Matches parameter documentation section to parameter documentation rules"""
+    def match_param_docs(self) -> tuple[set[str], set[str]]:
+        """Matches parameter documentation section to parameter documentation rules."""
         params_with_doc = set()
         params_with_type = set()
 
@@ -781,15 +797,26 @@ class NumpyDocstring(GoogleDocstring):
                 continue
 
             # check if parameter has description only
-            re_only_desc = re.match(r"\s*  (\*{0,2}\w+)\s*:?\n", entry)
+            re_only_desc = re.match(r"\s*(\*{0,2}\w+)\s*:?\n\s*\w*$", entry)
             if re_only_desc:
-                param_name = match.group(1)
-                param_desc = match.group(2)
+                param_name = match.group("param_name")
+                param_desc = match.group("param_type")
                 param_type = None
             else:
-                param_name = match.group(1)
-                param_type = match.group(3)
-                param_desc = match.group(4)
+                param_name = match.group("param_name")
+                param_type = match.group("param_type")
+                param_desc = match.group("param_desc")
+                # The re_param_line pattern needs to match multi-line which removes the ability
+                # to match a single line description like 'arg : a number type.'
+                # We are not trying to determine whether 'a number type' is correct typing
+                # but we do accept it as typing as it is in the place where typing
+                # should be
+                if param_type is None and re.match(r"\s*(\*{0,2}\w+)\s*:.+$", entry):
+                    param_type = param_desc
+                # If the description is "" but we have a type description
+                # we consider the description to be the type
+                if not param_desc and param_type:
+                    param_desc = param_type
 
             if param_type:
                 params_with_type.add(param_name)
@@ -800,11 +827,11 @@ class NumpyDocstring(GoogleDocstring):
         return params_with_doc, params_with_type
 
     @staticmethod
-    def min_section_indent(section_match):
+    def min_section_indent(section_match: re.Match[str]) -> int:
         return len(section_match.group(1))
 
     @staticmethod
-    def _is_section_header(line):
+    def _is_section_header(line: str) -> bool:
         return bool(re.match(r"\s*-+$", line))
 
 
