@@ -1,21 +1,30 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
 """Looks for overlapping exceptions."""
 
-import astroid
+from __future__ import annotations
 
-from pylint import checkers, interfaces
+from typing import TYPE_CHECKING, Any
+
+import astroid
+from astroid import nodes
+
+from pylint import checkers
 from pylint.checkers import utils
 from pylint.checkers.exceptions import _annotated_unpack_infer
 
+if TYPE_CHECKING:
+    from pylint.lint import PyLinter
+
 
 class OverlappingExceptionsChecker(checkers.BaseChecker):
     """Checks for two or more exceptions in the same exception handler
-    clause that are identical or parts of the same inheritance hierarchy
-    (i.e. overlapping)."""
+    clause that are identical or parts of the same inheritance hierarchy.
 
-    __implements__ = interfaces.IAstroidChecker
+    (i.e. overlapping).
+    """
 
     name = "overlap-except"
     msgs = {
@@ -25,12 +34,11 @@ class OverlappingExceptionsChecker(checkers.BaseChecker):
             "Used when exceptions in handler overlap or are identical",
         )
     }
-    priority = -2
     options = ()
 
-    @utils.check_messages("overlapping-except")
-    def visit_tryexcept(self, node):
-        """check for empty except"""
+    @utils.only_required_for_messages("overlapping-except")
+    def visit_tryexcept(self, node: nodes.TryExcept) -> None:
+        """Check for empty except."""
         for handler in node.handlers:
             if handler.type is None:
                 continue
@@ -41,12 +49,11 @@ class OverlappingExceptionsChecker(checkers.BaseChecker):
             except astroid.InferenceError:
                 continue
 
-            handled_in_clause = []
+            handled_in_clause: list[tuple[Any, Any]] = []
             for part, exc in excs:
                 if exc is astroid.Uninferable:
                     continue
                 if isinstance(exc, astroid.Instance) and utils.inherit_from_std_ex(exc):
-                    # pylint: disable=protected-access
                     exc = exc._proxied
 
                 if not isinstance(exc, astroid.ClassDef):
@@ -66,8 +73,7 @@ class OverlappingExceptionsChecker(checkers.BaseChecker):
                         self.add_message(
                             "overlapping-except",
                             node=handler.type,
-                            args="%s and %s are the same"
-                            % (prev_part.as_string(), part.as_string()),
+                            args=f"{prev_part.as_string()} and {part.as_string()} are the same",
                         )
                     elif prev_exc in exc_ancestors or exc in prev_exc_ancestors:
                         ancestor = part if exc in prev_exc_ancestors else prev_part
@@ -75,12 +81,10 @@ class OverlappingExceptionsChecker(checkers.BaseChecker):
                         self.add_message(
                             "overlapping-except",
                             node=handler.type,
-                            args="%s is an ancestor class of %s"
-                            % (ancestor.as_string(), descendant.as_string()),
+                            args=f"{ancestor.as_string()} is an ancestor class of {descendant.as_string()}",
                         )
                 handled_in_clause += [(part, exc)]
 
 
-def register(linter):
-    """Required method to auto register this checker."""
+def register(linter: PyLinter) -> None:
     linter.register_checker(OverlappingExceptionsChecker(linter))
