@@ -1,25 +1,15 @@
-# Copyright (c) 2008-2010, 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
-# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
-# Copyright (c) 2015-2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2015 Mike Frysinger <vapier@gentoo.org>
-# Copyright (c) 2015 Florian Bruhin <me@the-compiler.org>
-# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
-# Copyright (c) 2018, 2020 Anthony Sottile <asottile@umich.edu>
-# Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
-# Copyright (c) 2019-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2019 Kylian <development@goudcode.nl>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-# Copyright (c) 2021 Andreas Finkler <andi.finkler@gmail.com>
-# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
-# Copyright (c) 2021 Mark Byrne <31762852+mbyrnepr2@users.noreply.github.com>
-
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
-"""Utilities for creating VCG and Dot diagrams"""
+"""Utilities for creating VCG and Dot diagrams."""
 
+from __future__ import annotations
+
+import argparse
 import itertools
 import os
+from collections.abc import Iterable
 
 from astroid import modutils, nodes
 
@@ -30,18 +20,18 @@ from pylint.pyreverse.diagrams import (
     PackageDiagram,
     PackageEntity,
 )
-from pylint.pyreverse.printer import EdgeType, NodeProperties, NodeType
+from pylint.pyreverse.printer import EdgeType, NodeProperties, NodeType, Printer
 from pylint.pyreverse.printer_factory import get_printer_for_filetype
 from pylint.pyreverse.utils import is_exception
 
 
 class DiagramWriter:
-    """base class for writing project diagrams"""
+    """Base class for writing project diagrams."""
 
-    def __init__(self, config):
+    def __init__(self, config: argparse.Namespace) -> None:
         self.config = config
         self.printer_class = get_printer_for_filetype(self.config.output_format)
-        self.printer = None  # defined in set_printer
+        self.printer: Printer  # defined in set_printer
         self.file_name = ""  # defined in set_printer
         self.depth = self.config.max_color_depth
         self.available_colors = itertools.cycle(
@@ -65,24 +55,24 @@ class DiagramWriter:
                 "mediumspringgreen",
             ]
         )
-        self.used_colors = {}
+        self.used_colors: dict[str, str] = {}
 
-    def write(self, diadefs):
-        """write files for <project> according to <diadefs>"""
+    def write(self, diadefs: Iterable[ClassDiagram | PackageDiagram]) -> None:
+        """Write files for <project> according to <diadefs>."""
         for diagram in diadefs:
             basename = diagram.title.strip().replace(" ", "_")
             file_name = f"{basename}.{self.config.output_format}"
             if os.path.exists(self.config.output_directory):
                 file_name = os.path.join(self.config.output_directory, file_name)
             self.set_printer(file_name, basename)
-            if diagram.TYPE == "class":
-                self.write_classes(diagram)
-            else:
+            if isinstance(diagram, PackageDiagram):
                 self.write_packages(diagram)
+            else:
+                self.write_classes(diagram)
             self.save()
 
     def write_packages(self, diagram: PackageDiagram) -> None:
-        """write a package diagram"""
+        """Write a package diagram."""
         # sorted to get predictable (hence testable) results
         for module in sorted(diagram.modules(), key=lambda x: x.title):
             module.fig_id = module.node.qname()
@@ -100,9 +90,9 @@ class DiagramWriter:
             )
 
     def write_classes(self, diagram: ClassDiagram) -> None:
-        """write a class diagram"""
+        """Write a class diagram."""
         # sorted to get predictable (hence testable) results
-        for obj in sorted(diagram.objects, key=lambda x: x.title):
+        for obj in sorted(diagram.objects, key=lambda x: x.title):  # type: ignore[no-any-return]
             obj.fig_id = obj.node.qname()
             type_ = NodeType.INTERFACE if obj.shape == "interface" else NodeType.CLASS
             self.printer.emit_node(
@@ -130,21 +120,29 @@ class DiagramWriter:
                 label=rel.name,
                 type_=EdgeType.ASSOCIATION,
             )
+        # generate aggregations
+        for rel in diagram.get_relationships("aggregation"):
+            self.printer.emit_edge(
+                rel.from_object.fig_id,
+                rel.to_object.fig_id,
+                label=rel.name,
+                type_=EdgeType.AGGREGATION,
+            )
 
     def set_printer(self, file_name: str, basename: str) -> None:
-        """set printer"""
+        """Set printer."""
         self.printer = self.printer_class(basename)
         self.file_name = file_name
 
     def get_package_properties(self, obj: PackageEntity) -> NodeProperties:
-        """get label and shape for packages."""
+        """Get label and shape for packages."""
         return NodeProperties(
             label=obj.title,
             color=self.get_shape_color(obj) if self.config.colorized else "black",
         )
 
     def get_class_properties(self, obj: ClassEntity) -> NodeProperties:
-        """get label and shape for classes."""
+        """Get label and shape for classes."""
         properties = NodeProperties(
             label=obj.title,
             attrs=obj.attrs if not self.config.only_classnames else None,
@@ -155,7 +153,7 @@ class DiagramWriter:
         return properties
 
     def get_shape_color(self, obj: DiagramEntity) -> str:
-        """get shape color"""
+        """Get shape color."""
         qualified_name = obj.node.qname()
         if modutils.is_standard_module(qualified_name.split(".", maxsplit=1)[0]):
             return "grey"
@@ -171,5 +169,5 @@ class DiagramWriter:
         return self.used_colors[base_name]
 
     def save(self) -> None:
-        """write to disk"""
+        """Write to disk."""
         self.printer.generate(self.file_name)
