@@ -1,5 +1,9 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 from pylint.reporters.base_reporter import BaseReporter
@@ -9,7 +13,7 @@ if TYPE_CHECKING:
 
 
 class CollectingReporter(BaseReporter):
-    """collects messages"""
+    """Collects messages."""
 
     name = "collector"
 
@@ -20,5 +24,5 @@ class CollectingReporter(BaseReporter):
     def reset(self) -> None:
         self.messages = []
 
-    def _display(self, layout: "Section") -> None:
+    def _display(self, layout: Section) -> None:
         pass
