@@ -1,11 +1,13 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+
+from __future__ import annotations
 
 from io import StringIO
 from os import getcwd, sep
-from typing import TYPE_CHECKING, List, Optional
+from typing import TYPE_CHECKING
 
-from pylint import interfaces
 from pylint.message import Message
 from pylint.reporters import BaseReporter
 
@@ -14,9 +16,8 @@ if TYPE_CHECKING:
 
 
 class GenericTestReporter(BaseReporter):
-    """reporter storing plain text messages"""
+    """Reporter storing plain text messages."""
 
-    __implements__ = interfaces.IReporter
     out: StringIO
 
     def __init__(  # pylint: disable=super-init-not-called # See https://github.com/PyCQA/pylint/issues/4941
@@ -27,15 +28,15 @@ class GenericTestReporter(BaseReporter):
 
     def reset(self) -> None:
         self.out = StringIO()
-        self.messages: List[Message] = []
+        self.messages: list[Message] = []
 
     def handle_message(self, msg: Message) -> None:
-        """Append messages to the list of messages of the reporter"""
+        """Append messages to the list of messages of the reporter."""
         self.messages.append(msg)
 
     def finalize(self) -> str:
-        """Format and print messages in the context of the path"""
-        messages: List[str] = []
+        """Format and print messages in the context of the path."""
+        messages: list[str] = []
         for msg in self.messages:
             obj = ""
             if msg.obj:
@@ -50,32 +51,32 @@ class GenericTestReporter(BaseReporter):
         self.reset()
         return result
 
-    def on_set_current_module(self, module: str, filepath: Optional[str]) -> None:
+    def on_set_current_module(self, module: str, filepath: str | None) -> None:
         pass
 
     # pylint: enable=unused-argument
 
-    def display_reports(self, layout: "Section") -> None:
-        """ignore layouts"""
+    def display_reports(self, layout: Section) -> None:
+        """Ignore layouts."""
 
-    def _display(self, layout: "Section") -> None:
+    def _display(self, layout: Section) -> None:
         pass
 
 
 class MinimalTestReporter(BaseReporter):
-    def on_set_current_module(self, module: str, filepath: Optional[str]) -> None:
+    def on_set_current_module(self, module: str, filepath: str | None) -> None:
         self.messages = []
 
-    def _display(self, layout: "Section") -> None:
+    def _display(self, layout: Section) -> None:
         pass
 
 
 class FunctionalTestReporter(BaseReporter):
-    def on_set_current_module(self, module: str, filepath: Optional[str]) -> None:
+    def on_set_current_module(self, module: str, filepath: str | None) -> None:
         self.messages = []
 
-    def display_reports(self, layout: "Section") -> None:
+    def display_reports(self, layout: Section) -> None:
         """Ignore layouts and don't call self._display()."""
 
-    def _display(self, layout: "Section") -> None:
+    def _display(self, layout: Section) -> None:
         pass
