@@ -1,23 +1,27 @@
-"""Small script to get a new unused message id category"""
+"""Small script to get a new unused message id category."""
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
-from typing import List
+from __future__ import annotations
 
 from pylint.checkers import initialize as initialize_checkers
 from pylint.extensions import initialize as initialize_extensions
 from pylint.lint.pylinter import PyLinter
+from pylint.message._deleted_message_ids import DELETED_MSGID_PREFIXES
 
 
-def register_all_checkers_and_plugins(linter: "PyLinter") -> None:
-    """Registers all checkers and plugins"""
+def register_all_checkers_and_plugins(linter: PyLinter) -> None:
+    """Registers all checkers and plugins."""
     linter.cmdline_parser.set_conflict_handler("resolve")
     initialize_checkers(linter)
     initialize_extensions(linter)
 
 
-def get_next_code_category(message_ids: List[str]) -> int:
+def get_next_code_category(message_ids: list[str]) -> int:
     categories = sorted({int(i[:2]) for i in message_ids})
+    # We add the prefixes for deleted checkers
+    categories += DELETED_MSGID_PREFIXES
     for i in categories:
         if i + 1 not in categories:
             return i + 1
