@@ -1,29 +1,6 @@
-# Copyright (c) 2014 Google, Inc.
-# Copyright (c) 2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
-# Copyright (c) 2014 Holger Peters <email@holger-peters.de>
-# Copyright (c) 2015-2020 Claudiu Popa <pcmanticore@gmail.com>
-# Copyright (c) 2015 Dmitry Pribysh <dmand@yandex.ru>
-# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
-# Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
-# Copyright (c) 2016 Filipe Brandenburger <filbranden@google.com>
-# Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
-# Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
-# Copyright (c) 2019-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
-# Copyright (c) 2019 Martin Vielsmaier <martin.vielsmaier@gmail.com>
-# Copyright (c) 2019 Federico Bond <federicobond@gmail.com>
-# Copyright (c) 2020 Julien Palard <julien@palard.fr>
-# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
-# Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
-# Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
-# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
-# Copyright (c) 2021 David Liu <david@cs.toronto.edu>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
-# Copyright (c) 2021 David Gilman <davidgilman1@gmail.com>
-
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
 import astroid
 import pytest
@@ -46,7 +23,8 @@ needs_c_extension = pytest.mark.skipif(
 
 
 class TestTypeChecker(CheckerTestCase):
-    "Tests for pylint.checkers.typecheck"
+    """Tests for pylint.checkers.typecheck."""
+
     CHECKER_CLASS = typecheck.TypeChecker
 
     @set_config(suggestion_mode=False)
@@ -63,6 +41,10 @@ class TestTypeChecker(CheckerTestCase):
             node=node,
             args=("Module", "coverage.tracer", "CTracer", ""),
             confidence=INFERENCE,
+            line=3,
+            col_offset=0,
+            end_line=3,
+            end_col_offset=14,
         )
         with self.assertAddsMessages(message):
             self.checker.visit_attribute(node)
@@ -81,13 +63,18 @@ class TestTypeChecker(CheckerTestCase):
             node=node,
             args=("Module", "coverage.tracer", "CTracer", ""),
             confidence=INFERENCE,
+            line=3,
+            col_offset=0,
+            end_line=3,
+            end_col_offset=14,
         )
         with self.assertAddsMessages(message):
             self.checker.visit_attribute(node)
 
 
 class TestTypeCheckerOnDecorators(CheckerTestCase):
-    "Tests for pylint.checkers.typecheck on decorated functions."
+    """Tests for pylint.checkers.typecheck on decorated functions."""
+
     CHECKER_CLASS = typecheck.TypeChecker
 
     def test_issue3882_class_decorators(self) -> None:
@@ -128,6 +115,10 @@ class TestTypeCheckerOnDecorators(CheckerTestCase):
                 node=subscript.value,
                 args="collections",
                 confidence=UNDEFINED,
+                line=3,
+                col_offset=7,
+                end_line=3,
+                end_col_offset=18,
             )
         ):
             self.checker.visit_subscript(subscript)
@@ -179,6 +170,10 @@ class TestTypeCheckerOnDecorators(CheckerTestCase):
                 node=subscript.value,
                 args="decorated",
                 confidence=UNDEFINED,
+                line=18,
+                col_offset=7,
+                end_line=18,
+                end_col_offset=16,
             )
         ):
             self.checker.visit_subscript(subscript)
@@ -219,6 +214,10 @@ class TestTypeCheckerOnDecorators(CheckerTestCase):
                 node=subscript.value,
                 args="decorated",
                 confidence=UNDEFINED,
+                line=17,
+                col_offset=7,
+                end_line=17,
+                end_col_offset=16,
             )
         ):
             self.checker.visit_subscript(subscript)
