@@ -17,19 +17,19 @@ from pylint.typing import MessageDefinitionTuple
 
 
 def test__regexp_validator_valid() -> None:
-    result = config.option._regexp_validator(None, None, "test_.*")
+    result = config.option._regexp_validator(None, "", "test_.*")
     assert isinstance(result, re.Pattern)
     assert result.pattern == "test_.*"
 
 
 def test__regexp_validator_invalid() -> None:
     with pytest.raises(re.error):
-        config.option._regexp_validator(None, None, "test_)")
+        config.option._regexp_validator(None, "", "test_)")
 
 
 def test__csv_validator_no_spaces() -> None:
     values = ["One", "Two", "Three"]
-    result = config.option._csv_validator(None, None, ",".join(values))
+    result = config.option._csv_validator(None, "", ",".join(values))
     assert isinstance(result, list)
     assert len(result) == 3
     for i, value in enumerate(values):
@@ -38,7 +38,7 @@ def test__csv_validator_no_spaces() -> None:
 
 def test__csv_validator_spaces() -> None:
     values = ["One", "Two", "Three"]
-    result = config.option._csv_validator(None, None, ", ".join(values))
+    result = config.option._csv_validator(None, "", ", ".join(values))
     assert isinstance(result, list)
     assert len(result) == 3
     for i, value in enumerate(values):
@@ -47,7 +47,7 @@ def test__csv_validator_spaces() -> None:
 
 def test__regexp_csv_validator_valid() -> None:
     pattern_strings = ["test_.*", "foo\\.bar", "^baz$"]
-    result = config.option._regexp_csv_validator(None, None, ",".join(pattern_strings))
+    result = config.option._regexp_csv_validator(None, "", ",".join(pattern_strings))
     for i, regex in enumerate(result):
         assert isinstance(regex, re.Pattern)
         assert regex.pattern == pattern_strings[i]
@@ -56,7 +56,7 @@ def test__regexp_csv_validator_valid() -> None:
 def test__regexp_csv_validator_invalid() -> None:
     pattern_strings = ["test_.*", "foo\\.bar", "^baz)$"]
     with pytest.raises(re.error):
-        config.option._regexp_csv_validator(None, None, ",".join(pattern_strings))
+        config.option._regexp_csv_validator(None, "", ",".join(pattern_strings))
 
 
 class TestPyLinterOptionSetters(CheckerTestCase):
