@@ -7,13 +7,16 @@
 from __future__ import annotations
 
 import os
+from collections.abc import Callable
 from pathlib import Path
 
 import pytest
 
 from pylint import checkers
+from pylint.checkers import BaseChecker
 from pylint.lint import PyLinter
 from pylint.lint.run import _cpu_count
+from pylint.reporters import BaseReporter
 from pylint.testutils import MinimalTestReporter
 
 HERE = Path(__file__).parent
@@ -25,7 +28,13 @@ def tests_directory() -> Path:
 
 
 @pytest.fixture
-def linter(checker, register, enable, disable, reporter):
+def linter(
+    checker: type[BaseChecker] | None,
+    register: Callable[[PyLinter], None] | None,
+    enable: str | None,
+    disable: str | None,
+    reporter: type[BaseReporter],
+) -> PyLinter:
     _linter = PyLinter()
     _linter.set_reporter(reporter())
     checkers.initialize(_linter)
@@ -44,31 +53,31 @@ def linter(checker, register, enable, disable, reporter):
 
 
 @pytest.fixture(scope="module")
-def checker():
+def checker() -> None:
     return None
 
 
 @pytest.fixture(scope="module")
-def register():
+def register() -> None:
     return None
 
 
 @pytest.fixture(scope="module")
-def enable():
+def enable() -> None:
     return None
 
 
 @pytest.fixture(scope="module")
-def disable():
+def disable() -> None:
     return None
 
 
 @pytest.fixture(scope="module")
-def reporter():
+def reporter() -> type[MinimalTestReporter]:
     return MinimalTestReporter
 
 
-def pytest_addoption(parser) -> None:
+def pytest_addoption(parser: pytest.Parser) -> None:
     parser.addoption(
         "--primer-stdlib",
         action="store_true",
