@@ -3,8 +3,12 @@
 # Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
 """Unit tests for utils functions in :mod:`pylint.extensions._check_docs_utils`."""
+
+from __future__ import annotations
+
 import astroid
 import pytest
+from astroid import nodes
 
 from pylint.extensions import _check_docs_utils as utils
 
@@ -134,7 +138,7 @@ def test_space_indentation(string: str, count: int) -> None:
         ),
     ],
 )
-def test_exception(raise_node, expected):
+def test_exception(raise_node: nodes.NodeNG, expected: set[str]) -> None:
     found_nodes = utils.possible_exc_types(raise_node)
     for node in found_nodes:
         assert isinstance(node, astroid.nodes.ClassDef)
