@@ -1,10 +1,10 @@
 """
-'typing.NoReturn' is broken inside compond types for Python 3.7.0
+'typing.NoReturn' is broken inside compound types for Python 3.7.0
 https://bugs.python.org/issue34921
 
 If no runtime introspection is required, use string annotations instead.
 """
-# pylint: disable=missing-docstring
+# pylint: disable=missing-docstring, broad-exception-raised
 import typing
 from typing import TYPE_CHECKING, Callable, NoReturn, Union
 
