@@ -2,7 +2,7 @@
 import os
 
 
-foo = [
+test = [
     f"{łol}                                                                       "
     for łol in os.listdir(".")  # [non-ascii-name]
 ]
