@@ -89,9 +89,9 @@ def used_before_assignment(*, arg): return arg + 1
 # Test for #4021
 # https://github.com/PyCQA/pylint/issues/4021
 class MetaClass(type):
-    def __new__(cls, *args, parameter=None, **kwargs):
+    def __new__(mcs, *args, parameter=None, **kwargs):
         print(parameter)
-        return super().__new__(cls, *args, **kwargs)
+        return super().__new__(mcs, *args, **kwargs)
 
 
 class InheritingClass(metaclass=MetaClass, parameter=variable):  # [undefined-variable]
