@@ -1,6 +1,6 @@
 """Tests for useless suppressions"""
 # pylint: enable=useless-suppression, line-too-long
-# pylint: disable=unused-import, wrong-import-order
+# pylint: disable=unused-import, wrong-import-order, wrong-import-position
 
 # False positive for wrong-import-order
 # Reported in https://github.com/PyCQA/pylint/issues/2366
@@ -10,3 +10,7 @@ import astroid
 # False-positive for 'line-too-long'
 # Reported in https://github.com/PyCQA/pylint/issues/4212
 VAR = "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX" # pylint: disable=line-too-long
+
+# False-positive for 'wrong-import-order'
+# Reported in https://github.com/PyCQA/pylint/issues/5219
+import os
