@@ -2,6 +2,8 @@
 # For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
 # Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
 
+from __future__ import annotations
+
 from contextlib import redirect_stdout
 from io import StringIO
 
@@ -13,6 +15,7 @@ from pylint.exceptions import InvalidMessageError, UnknownMessageError
 from pylint.lint.pylinter import PyLinter
 from pylint.message import MessageDefinition
 from pylint.message.message_definition_store import MessageDefinitionStore
+from pylint.typing import MessageDefinitionTuple
 
 
 @pytest.mark.parametrize(
@@ -120,7 +123,11 @@ from pylint.message.message_definition_store import MessageDefinitionStore
         ),
     ],
 )
-def test_register_error(empty_store, messages, expected):
+def test_register_error(
+    empty_store: MessageDefinitionStore,
+    messages: dict[str, MessageDefinitionTuple],
+    expected: str,
+) -> None:
     class Checker(BaseChecker):
         def __init__(self) -> None:
             super().__init__(PyLinter())
