@@ -11,7 +11,8 @@ import warnings
 from contextlib import redirect_stdout
 from io import StringIO
 from json import dumps
-from typing import TYPE_CHECKING
+from pathlib import Path
+from typing import TYPE_CHECKING, TextIO
 
 import pytest
 from _pytest.recwarn import WarningsRecorder
@@ -29,16 +30,16 @@ if TYPE_CHECKING:
 
 
 @pytest.fixture(scope="module")
-def reporter():
+def reporter() -> type[TextReporter]:
     return TextReporter
 
 
 @pytest.fixture(scope="module")
-def disable():
+def disable() -> list[str]:
     return ["I"]
 
 
-def test_template_option(linter):
+def test_template_option(linter: PyLinter) -> None:
     output = StringIO()
     linter.reporter.out = output
     linter.config.msg_template = "{msg_id}:{line:03d}"
@@ -49,7 +50,7 @@ def test_template_option(linter):
     assert output.getvalue() == "************* Module 0123\nC0301:001\nC0301:002\n"
 
 
-def test_template_option_default(linter) -> None:
+def test_template_option_default(linter: PyLinter) -> None:
     """Test the default msg-template setting."""
     output = StringIO()
     linter.reporter.out = output
@@ -63,7 +64,7 @@ def test_template_option_default(linter) -> None:
     assert out_lines[2] == "my_module:2:0: C0301: Line too long (3/4) (line-too-long)"
 
 
-def test_template_option_end_line(linter) -> None:
+def test_template_option_end_line(linter: PyLinter) -> None:
     """Test the msg-template option with end_line and end_column."""
     output = StringIO()
     linter.reporter.out = output
@@ -82,7 +83,7 @@ def test_template_option_end_line(linter) -> None:
     assert out_lines[2] == "my_mod:2:0:2:4: C0301: Line too long (3/4) (line-too-long)"
 
 
-def test_template_option_non_existing(linter) -> None:
+def test_template_option_non_existing(linter: PyLinter) -> None:
     """Test the msg-template option with non-existent options.
     This makes sure that this option remains backwards compatible as new
     parameters do not break on previous versions
@@ -137,7 +138,7 @@ def test_deprecation_set_output(recwarn: WarningsRecorder) -> None:
     assert reporter.out == sys.stdout
 
 
-def test_parseable_output_deprecated():
+def test_parseable_output_deprecated() -> None:
     with warnings.catch_warnings(record=True) as cm:
         warnings.simplefilter("always")
         ParseableTextReporter()
@@ -146,9 +147,10 @@ def test_parseable_output_deprecated():
     assert isinstance(cm[0].message, DeprecationWarning)
 
 
-def test_parseable_output_regression():
+def test_parseable_output_regression() -> None:
     output = StringIO()
     with warnings.catch_warnings(record=True):
+        warnings.simplefilter("ignore", category=DeprecationWarning)
         linter = PyLinter(reporter=ParseableTextReporter())
 
     checkers.initialize(linter)
@@ -169,18 +171,18 @@ class NopReporter(BaseReporter):
     name = "nop-reporter"
     extension = ""
 
-    def __init__(self, output=None):
+    def __init__(self, output: TextIO | None = None) -> None:
         super().__init__(output)
         print("A NopReporter was initialized.", file=self.out)
 
-    def writeln(self, string=""):
+    def writeln(self, string: str = "") -> None:
         pass
 
     def _display(self, layout: Section) -> None:
         pass
 
 
-def test_multi_format_output(tmp_path):
+def test_multi_format_output(tmp_path: Path) -> None:
     text = StringIO(newline=None)
     json = tmp_path / "somefile.json"
 
@@ -205,12 +207,15 @@ def test_multi_format_output(tmp_path):
             linter.reporter.out = text
 
         linter.open()
-        linter.check_single_file_item(FileItem("somemodule", source_file, "somemodule"))
+        linter.check_single_file_item(
+            FileItem("somemodule", str(source_file), "somemodule")
+        )
         linter.add_message("line-too-long", line=1, args=(1, 2))
         linter.generate_reports()
         linter.reporter.writeln("direct output")
 
         # Ensure the output files are flushed and closed
+        assert isinstance(linter.reporter, MultiReporter)
         linter.reporter.close_output_files()
         del linter.reporter
 
