@@ -111,7 +111,7 @@ class ParallelTestChecker(BaseRawFileChecker):
         for _ in self.data[1::2]:  # Work on pairs of files, see class docstring.
             self.add_message("R9999", args=("From process_module, two files seen.",))
 
-    def get_map_data(self):
+    def get_map_data(self) -> list[str]:
         return self.data
 
     def reduce_map_data(self, linter: PyLinter, data: list[list[str]]) -> None:
@@ -162,10 +162,10 @@ class ThirdParallelTestChecker(ParallelTestChecker):
 class TestCheckParallelFramework:
     """Tests the check_parallel() function's framework."""
 
-    def setup_class(self):
+    def setup_class(self) -> None:
         self._prev_global_linter = pylint.lint.parallel._worker_linter
 
-    def teardown_class(self):
+    def teardown_class(self) -> None:
         pylint.lint.parallel._worker_linter = self._prev_global_linter
 
     def test_worker_initialize(self) -> None:
@@ -191,7 +191,7 @@ class TestCheckParallelFramework:
     def test_worker_check_single_file_uninitialised(self) -> None:
         pylint.lint.parallel._worker_linter = None
         with pytest.raises(  # Objects that do not match the linter interface will fail
-            Exception, match="Worker linter not yet initialised"
+            RuntimeError, match="Worker linter not yet initialised"
         ):
             worker_check_single_file(_gen_file_data())
 
@@ -240,7 +240,9 @@ class TestCheckParallelFramework:
         linter.load_plugin_modules(["pylint.extensions.overlapping_exceptions"])
         try:
             dill.dumps(linter)
-            assert False, "Plugins loaded were pickle-safe! This test needs altering"
+            raise AssertionError(
+                "Plugins loaded were pickle-safe! This test needs altering"
+            )
         except (KeyError, TypeError, PickleError, NotImplementedError):
             pass
 
@@ -248,8 +250,10 @@ class TestCheckParallelFramework:
         linter.load_plugin_configuration()
         try:
             dill.dumps(linter)
-        except KeyError:
-            assert False, "Cannot pickle linter when using non-pickleable plugin"
+        except KeyError as exc:
+            raise AssertionError(
+                "Cannot pickle linter when using non-pickleable plugin"
+            ) from exc
 
     def test_worker_check_sequential_checker(self) -> None:
         """Same as test_worker_check_single_file_no_checkers with SequentialTestChecker."""
@@ -431,7 +435,9 @@ class TestCheckParallel:
             (10, 2, 3),
         ],
     )
-    def test_compare_workers_to_single_proc(self, num_files, num_jobs, num_checkers):
+    def test_compare_workers_to_single_proc(
+        self, num_files: int, num_jobs: int, num_checkers: int
+    ) -> None:
         """Compares the 3 key parameters for check_parallel() produces the same results.
 
         The intent here is to ensure that the check_parallel() operates on each file,
@@ -528,7 +534,7 @@ class TestCheckParallel:
             (10, 2, 3),
         ],
     )
-    def test_map_reduce(self, num_files, num_jobs, num_checkers):
+    def test_map_reduce(self, num_files: int, num_jobs: int, num_checkers: int) -> None:
         """Compares the 3 key parameters for check_parallel() produces the same results.
 
         The intent here is to validate the reduce step: no stats should be lost.
