@@ -6,7 +6,7 @@
 
 from __future__ import annotations
 
-from collections.abc import Callable
+import sys
 
 import pytest
 
@@ -16,9 +16,19 @@ from pylint.message import Message
 from pylint.testutils.output_line import OutputLine
 from pylint.typing import MessageLocationTuple
 
+if sys.version_info >= (3, 8):
+    from typing import Protocol
+else:
+    from typing_extensions import Protocol
+
+
+class _MessageCallable(Protocol):
+    def __call__(self, confidence: Confidence = HIGH) -> Message:
+        ...
+
 
 @pytest.fixture()
-def message() -> Callable:
+def message() -> _MessageCallable:
     def inner(confidence: Confidence = HIGH) -> Message:
         return Message(
             symbol="missing-docstring",
@@ -55,7 +65,7 @@ def test_output_line() -> None:
     assert output_line.confidence == "HIGH"
 
 
-def test_output_line_from_message(message: Callable) -> None:
+def test_output_line_from_message(message: _MessageCallable) -> None:
     """Test that the OutputLine NamedTuple is instantiated correctly with from_msg."""
     expected_column = 2 if PY38_PLUS else 0
 
@@ -91,7 +101,7 @@ def test_output_line_from_message(message: Callable) -> None:
 
 
 @pytest.mark.parametrize("confidence", [HIGH, INFERENCE])
-def test_output_line_to_csv(confidence: Confidence, message: Callable) -> None:
+def test_output_line_to_csv(confidence: Confidence, message: _MessageCallable) -> None:
     """Test that the OutputLine NamedTuple is instantiated correctly with from_msg
     and then converted to csv.
     """
